import { OnDestroy } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';
import { INotification } from './others/notification-helper';
import { NgxNotifierService } from './services/ngx-notifier.service';
import * as i0 from "@angular/core";
/**
 * Notifier compoent, which holds all the notifications can be accessed via `ngx-notifier` selector
 */
export declare class NgxNotifierComponent implements OnDestroy {
    private ngxNotifierService;
    private domSanitizer;
    private componentDestroyed$;
    /** whether to allow duplicate messages or not */
    allowDuplicates: boolean;
    /** allow HTML in notification */
    allowHTML: boolean;
    /** custom class to be attached */
    className: string;
    /** default duration for dismissing notifications (60s/1minute) */
    duration: number;
    /** weather to enable or disable animations */
    disableAnimations: boolean;
    /** click to dismiss a notification */
    dismissOnClick: boolean;
    /** whether to insert on top or at bottom */
    insertOnTop: boolean;
    /** Maximum number of notifications to keep */
    max: number;
    /** array of notifications */
    notifications: INotification[];
    /** id of last inserted message */
    private lastInsertedNotificationId;
    /**
     * NgxNotifierComponent Constructor
     *
     * @param ngxNotifierService subscribe to get values form notifier service
     */
    constructor(ngxNotifierService: NgxNotifierService, domSanitizer: DomSanitizer);
    /**
     * updates notification into the array i.e., Which is the display
     *
     * @param notification notification element
     */
    private updateNotifications;
    /**
     * remove the element from the array based on index
     *
     * @param index position of the element
     */
    removeNotification(index: number): void;
    /**
     * click event when toast is cleared
     *
     * @param index position of the element
     */
    onToastClick(index: number): void;
    /** clear last inserted toast notification */
    private clearLastToast;
    /** stop subscription when component is destroyed */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxNotifierComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxNotifierComponent, "ngx-notifier", never, { "allowDuplicates": "allowDuplicates"; "allowHTML": "allowHTML"; "className": "className"; "duration": "duration"; "disableAnimations": "disableAnimations"; "dismissOnClick": "dismissOnClick"; "insertOnTop": "insertOnTop"; "max": "max"; }, {}, never, never>;
}
